@@ -1,6 +1,7 @@
-from .pipestat import main
 import sys
 
+from .cli import main
+
 if __name__ == "__main__":
     try:
         sys.exit(main())
