@@ -40,15 +40,11 @@ def main():
         if psm.schema is None:
             raise SchemaNotFoundError(msg="report", cli=True)
         result_metadata = psm.schema[args.result_identifier]
-        if (
-            result_metadata[SCHEMA_TYPE_KEY]
-            in [
-                "object",
-                "image",
-                "file",
-            ]
-            and os.path.exists(expandpath(value))
-        ):
+        if result_metadata[SCHEMA_TYPE_KEY] in [
+            "object",
+            "image",
+            "file",
+        ] and os.path.exists(expandpath(value)):
             from json import load
 
             _LOGGER.info(
