@@ -471,10 +471,19 @@ class PipestatManager(dict):
         """
         if not self.is_db_connected():
             self.establish_db_connection()
-        with self[DB_SESSION_KEY]() as session:
-            _LOGGER.debug("Created session")
+        # with self[DB_SESSION_KEY]() as session:
+        session = self[DB_SESSION_KEY]()
+        _LOGGER.debug("Created session")
+        try:
             yield session
-            _LOGGER.debug("Ending session")
+        except:
+            _LOGGER.info("session.rollback")
+            session.rollback()
+            raise
+        finally:
+            _LOGGER.info("session.close")
+            session.close()
+        _LOGGER.debug("Ending session")
 
     def _get_flag_file(
         self, record_identifier: str = None
@@ -896,7 +905,7 @@ class PipestatManager(dict):
         """
         Create a dictionary from the database table data
         """
-        with self.session as s:
+        with self[DB_SESSION_KEY]() as s:
             records = s.query(self.get_orm(self.namespace)).all()
         _LOGGER.debug(f"Reading data from database for '{self.namespace}' namespace")
         for record in records:
@@ -937,7 +946,7 @@ class PipestatManager(dict):
         """
         from sqlalchemy import inspect
 
-        with self.session as s:
+        with self[DB_SESSION_KEY]() as s:
             return inspect(s.bind).has_table(table_name=table_name)
 
     def _count_rows(self, table_name: str) -> int:
@@ -947,7 +956,7 @@ class PipestatManager(dict):
         :param str table_name: table to count rows for
         :return int: number of rows in the selected table
         """
-        with self.session as s:
+        with self[DB_SESSION_KEY]() as s:
             return s.query(self[DB_ORMS_KEY][table_name].id).count()
 
     def get_orm(self, table_name: str = None) -> Any:
@@ -981,7 +990,7 @@ class PipestatManager(dict):
         :return bool: whether the record exists in the table
         """
         if self.file is None:
-            with self.session as s:
+            with self[DB_SESSION_KEY]() as s:
                 return (
                     s.query(self.get_orm(table_name).id)
                     .filter_by(record_identifier=record_identifier)
@@ -1039,7 +1048,7 @@ class PipestatManager(dict):
         """
         table_name = table_name or self.namespace
         rid = self._strict_record_id(rid)
-        with self.session as s:
+        with self[DB_SESSION_KEY]() as s:
             record = (
                 s.query(self.get_orm(table_name))
                 .filter_by(record_identifier=rid)
@@ -1102,7 +1111,7 @@ class PipestatManager(dict):
         """
 
         ORM = self.get_orm(table_name or self.namespace)
-        with self.session as s:
+        with self[DB_SESSION_KEY]() as s:
             if columns is not None:
                 query = s.query(*[getattr(ORM, column) for column in columns])
             else:
@@ -1120,6 +1129,21 @@ class PipestatManager(dict):
             result = query.all()
         return result
 
+    def select_distinct(self, table_name, columns) -> List[Any]:
+        """
+        Perform a `SELECT DISTINCT` on given table and column
+
+        :param str table_name: name of the table to SELECT from
+        :param List[str] columns: columns to include in the result
+        """
+
+        ORM = self.get_orm(table_name or self.namespace)
+        with self[DB_SESSION_KEY]() as s:
+            query = s.query(*[getattr(ORM, column) for column in columns])
+            query = query.distinct()
+            result = query.all()
+        return result
+
     def retrieve(
         self,
         record_identifier: Optional[str] = None,
@@ -1187,7 +1211,7 @@ class PipestatManager(dict):
                     f"'{record_identifier}'"
                 )
 
-        with self.session as s:
+        with self[DB_SESSION_KEY]() as s:
             record = (
                 s.query(self.get_orm(table_name))
                 .filter_by(record_identifier=record_identifier)
@@ -1206,6 +1230,7 @@ class PipestatManager(dict):
 
     def select_txt(
         self,
+        columns: Optional[List[str]] = None,
         filter_templ: Optional[str] = "",
         filter_params: Optional[Dict[str, Any]] = {},
         table_name: Optional[str] = None,
@@ -1232,12 +1257,16 @@ class PipestatManager(dict):
                 f"The {self.__class__.__name__} object is not backed by a database. "
                 f"This operation is not supported for file backend."
             )
-        with self.session as s:
-            q = (
-                s.query(self.get_orm(table_name or self.namespace))
-                .filter(text(filter_templ))
-                .params(**filter_params)
-            )
+        ORM = self.get_orm(table_name or self.namespace)
+        with self[DB_SESSION_KEY]() as s:
+            if columns is not None:
+                q = (
+                    s.query(*[getattr(ORM, column) for column in columns])
+                    .filter(text(filter_templ))
+                    .params(**filter_params)
+                )
+            else:
+                q = s.query(ORM).filter(text(filter_templ)).params(**filter_params)
             if isinstance(offset, int):
                 q = q.offset(offset)
             if isinstance(limit, int):
@@ -1358,12 +1387,12 @@ class PipestatManager(dict):
             record_identifier=record_identifier, table_name=table_name
         ):
             new_record = ORMClass(**values)
-            with self.session as s:
+            with self[DB_SESSION_KEY]() as s:
                 s.add(new_record)
                 s.commit()
                 returned_id = new_record.id
         else:
-            with self.session as s:
+            with self[DB_SESSION_KEY]() as s:
                 record_to_update = (
                     s.query(ORMClass)
                     .filter(getattr(ORMClass, RECORD_ID) == record_identifier)
@@ -1481,7 +1510,7 @@ class PipestatManager(dict):
         if self.check_record_exists(
             record_identifier=record_identifier, table_name=table_name
         ):
-            with self.session as s:
+            with self[DB_SESSION_KEY]() as s:
                 records = s.query(ORMClass).filter(
                     getattr(ORMClass, RECORD_ID) == record_identifier
                 )
